/**
 * 设置更新echarts
 * @param {*} id 
 * @param {*} option 
 */
function updateChartOption(id, option) {
    let currentDom = document.querySelector(`#${id}`);
    let myChart = echarts.getInstanceByDom(currentDom);
    if (!myChart) {
        myChart = echarts.init(currentDom);
    }
    myChart.setOption(option);
}

export default {
    // 圆柱图
    updateCylinderChart(cylinderData = [], id) {
        // 提示框标题
        const tipTitle = '消防到位';
        // x轴单位名称
        let xData = []; 
        // y轴数据
        let yData = []; 

        cylinderData.forEach(ele => {
            xData.push(ele.name);
            yData.push(ele.num);
        });

        let option = {
            tooltip: {
                // 格式化提示内容
                formatter: function (params) {
                    return `${tipTitle}<br/>` +
                        "<span style='display:inline-block;margin-right:5px;border-radius:10px;width:9px;height:9px;background-color:rgba(55, 255, 238, 0.8)'></span>" +
                        params.name + ' : ' + params.value + '<br/>'
                }
            },
            grid: {
                left: '0',
                top: '18',
                right: '0',
                bottom: '0',
                containLabel: true
            },
            xAxis: [{
                data: xData,
                axisLabel: {
                    textStyle: {
                        color: 'rgba(255, 255, 255, 0.8)',
                        fontSize: '14',
                        fontFamily: 'SourceHanSansCN-Regular',
                        fontWeight: 400
                    },
                    margin: 10 //刻度标签与轴线之间的距离
                },

                axisLine: {
                    show: true,
                    lineStyle: {
                        color: 'rgba(255, 255, 255, 0.2)'
                    }
                },
                axisTick: {
                    show: false //不显示刻度
                },
                boundaryGap: true,
                splitLine: {
                    show: false,
                    width: 0.08,
                    lineStyle: {
                        type: "solid",
                        color: "#03202E"
                    }
                }
            }],
            yAxis: [{
                max: 10,
                splitLine: {
                    show: true,
                    lineStyle: {
                        color: 'rgba(255, 255, 255, 0.1)',
                        type: 'dashed'
                    }
                },
                axisTick: {
                    show: false
                },
                axisLine: {
                    show: true,
                    lineStyle: {
                        color: 'rgba(255, 255, 255, 0.2)'
                    }
                },
                axisLabel: {
                    textStyle: {
                        color: 'rgba(255, 255, 255, 0.8)',
                        fontSize: '14',
                        fontFamily: 'SourceHanSansCN-Regular',
                        fontWeight: 400
                    }
                }
            }],
            series: [
                //柱底圆片
                {
                    name: "",
                    type: "pictorialBar",
                    symbolSize: [10, 6], //调整截面形状
                    symbolOffset: [0, 0],
                    z: 12,
                    itemStyle: {
                        normal: {
                            color: 'rgba(22, 255, 241, 0.8)'
                        }
                    },
                    data: yData
                },
                //柱体
                {
                    name: tipTitle,
                    type: "bar",
                    barWidth: 10,
                    barGap: "0%",
                    itemStyle: {
                        normal: {
                            barBorderRadius: 5,
                            color: {
                                x: 0,
                                y: 0,
                                x2: 0,
                                y2: 1,
                                type: "linear",
                                global: false,
                                colorStops: [{
                                    offset: 0,
                                    color: "rgba(55, 255, 238, 0.2)"
                                }, {
                                    offset: 1,
                                    color: "rgba(55, 255, 238, 0.8)"
                                }]
                            }
                        }
                    },

                    data: yData
                },
                //柱顶圆片
                {
                    name: "",
                    type: "pictorialBar",
                    //调整截面形状
                    symbolSize: [10, 6],
                    symbolOffset: [0, -2],
                    z: 12,
                    symbolPosition: "end",
                    itemStyle: {
                        normal: {
                            color: 'rgba(22, 255, 241, 0.6)'
                        }
                    },
                    data: yData
                }
            ]
        };

        updateChartOption(id, option);
    },
    // 立体柱图
    updateDimensionalBarChart(xData = [],yData = [],id) {
        // 最大值
        const max = 100;
        // 绘制左侧面
        const CubeLeft = echarts.graphic.extendShape({
            shape: {
                x: 0,
                y: 0
            },
            buildPath: function (ctx, shape) {
                // 会canvas的应该都能看得懂，shape是从custom传入的
                const xAxisPoint = shape.xAxisPoint
                const c0 = [shape.x, shape.y]
                const c1 = [shape.x - 8, shape.y - 8]
                const c2 = [xAxisPoint[0] - 8, xAxisPoint[1] - 8]
                const c3 = [xAxisPoint[0], xAxisPoint[1]]
                ctx.moveTo(c0[0], c0[1]).lineTo(c1[0], c1[1]).lineTo(c2[0], c2[1]).lineTo(c3[0], c3[1]).closePath()
            }
        })
        // 绘制右侧面
        const CubeRight = echarts.graphic.extendShape({
            shape: {
                x: 0,
                y: 0
            },
            buildPath: function (ctx, shape) {
                const xAxisPoint = shape.xAxisPoint
                const c1 = [shape.x, shape.y]
                const c2 = [xAxisPoint[0], xAxisPoint[1]]
                const c3 = [xAxisPoint[0] + 7, xAxisPoint[1] - 7]
                const c4 = [shape.x + 9, shape.y - 9]
                ctx.moveTo(c1[0], c1[1]).lineTo(c2[0], c2[1]).lineTo(c3[0], c3[1]).lineTo(c4[0], c4[1]).closePath()
            }
        })
        // 绘制顶面
        const CubeTop = echarts.graphic.extendShape({
            shape: {
                x: 0,
                y: 0
            },
            buildPath: function (ctx, shape) {
                const c1 = [shape.x, shape.y]
                const c2 = [shape.x + 9, shape.y - 9]
                const c3 = [shape.x - 1, shape.y - 16]
                const c4 = [shape.x - 8, shape.y - 8]
                ctx.moveTo(c1[0], c1[1]).lineTo(c2[0], c2[1]).lineTo(c3[0], c3[1]).lineTo(c4[0], c4[1]).closePath()
            }
        })
        // 注册三个面图形
        echarts.graphic.registerShape('CubeLeft', CubeLeft)
        echarts.graphic.registerShape('CubeRight', CubeRight)
        echarts.graphic.registerShape('CubeTop', CubeTop)

        // 处理数据
        let dateArr = xData;
        let maxBarDataArr = new Array(dateArr.length).fill(max);
        let barData = yData;
        // 生成图表option
        let option = {
            tooltip: {
                trigger: 'axis',
                axisPointer: {
                    type: 'shadow'
                },
                formatter: function (params, ticket, callback) {
                    const item = params[1]
                    return item.name + ' : ' + item.value;
                }
            },
            grid: {
                left: 5,
                right: 30,
                bottom: 30,
                top: 50,
                containLabel: true
            },

            xAxis: {
                type: 'category',
                data: dateArr,
                axisLine: {
                    show: true,
                    lineStyle: {
                        color: '#4E4E4E'
                    }
                },
                offset: 25,
                axisTick: {
                    show: false,
                    length: 9,
                    alignWithLabel: true,
                    lineStyle: {
                        color: '#7DFFFD'
                    }
                },
                axisLabel: {
                    show: true,
                    fontSize: 12,
                    color: 'rgba(189,189,189,0.5)',
                    margin: -10,
                    fontFamily: "customFont"
                },
            },
            yAxis: [{
                    type: 'value',
                    axisLine: {
                        show: false,
                        lineStyle: {
                            color: 'white'
                        }
                    },
                    splitLine: {
                        show: true,
                        lineStyle: {
                            color: "rgba(255,255,255,0.2)",
                            type: 'dotted'
                        }
                    },
                    axisTick: {
                        show: false
                    },
                    axisLabel: {
                        show: true,
                        fontSize: 12,
                        color: 'rgba(189,189,189,0.5)',
                        fontFamily: "customFont"
                    }
                },
                {
                    type: 'value',
                    axisLine: {
                        show: false,
                        lineStyle: {
                            color: 'white'
                        }
                    },
                    splitLine: {
                        show: false,
                        lineStyle: {
                            color: "rgba(255,255,255,0.2)",
                            type: 'dotted'
                        }
                    },
                    axisTick: {
                        show: false
                    },
                    max: 100,
                    axisLabel: {
                        show: true,
                        fontSize: 12,
                        formatter: '{value}',
                        color: 'rgba(189,189,189,0.5)',
                    }
                },
                {
                    type: 'value',
                    axisLine: {
                        show: false,
                        lineStyle: {
                            color: 'white'
                        }
                    },
                    splitLine: {
                        show: false,
                        lineStyle: {
                            color: "rgba(255,255,255,0.2)",
                            type: 'dotted'
                        }
                    },
                    axisTick: {
                        show: false
                    },
                    axisLabel: {
                        show: false,
                        fontSize: 12,
                        formatter: '{value}',
                        color: 'rgba(189,189,189,0.5)',
                        fontFamily: "customFont"
                    }
                }

            ],
            series: [
                {
                    type: 'custom',
                    renderItem: function (params, api) {
                        const location = api.coord([api.value(0), api.value(1)])
                        return {
                            type: 'group',
                            children: [{
                                type: 'CubeLeft',
                                shape: {
                                    api,
                                    x: location[0],
                                    y: location[1],
                                    xAxisPoint: api.coord([api.value(0), 0])
                                },
                                style: {
                                    fill: 'rgba(12,50,32,1)'
                                }
                            }, {
                                type: 'CubeRight',
                                shape: {
                                    api,
                                    x: location[0],
                                    y: location[1],
                                    xAxisPoint: api.coord([api.value(0), 0])
                                },
                                style: {
                                    fill: 'rgba(10,41,26,1)'
                                }
                            }, {
                                type: 'CubeTop',
                                shape: {
                                    api,
                                    x: location[0],
                                    y: location[1],
                                    xAxisPoint: api.coord([api.value(0), 0])
                                },
                                style: {
                                    fill: 'rgba(8,35,22,1)'
                                }
                            }]
                        }
                    },
                    data: maxBarDataArr
                }, {
                    type: 'custom',
                    renderItem: (params, api) => {
                        const location = api.coord([api.value(0), api.value(1)])
                        var color = 'rgb(28,177,108)'
                        return {
                            type: 'group',
                            children: [{
                                type: 'CubeLeft',
                                shape: {
                                    api,
                                    xValue: api.value(0),
                                    yValue: api.value(1),
                                    x: location[0],
                                    y: location[1],
                                    xAxisPoint: api.coord([api.value(0), 0])
                                },
                                style: {
                                    fill: color
                                }
                            }, {
                                type: 'CubeRight',
                                shape: {
                                    api,
                                    xValue: api.value(0),
                                    yValue: api.value(1),
                                    x: location[0],
                                    y: location[1],
                                    xAxisPoint: api.coord([api.value(0), 0])
                                },
                                style: {
                                    fill: color
                                }
                            }, {
                                type: 'CubeTop',
                                shape: {
                                    api,
                                    xValue: api.value(0),
                                    yValue: api.value(1),
                                    x: location[0],
                                    y: location[1],
                                    xAxisPoint: api.coord([api.value(0), 0])
                                },
                                style: {
                                    fill: color
                                }
                            }]
                        }
                    },
                    data: barData
                }, {
                    type: 'bar',
                    itemStyle: {
                        color: 'transparent'
                    },
                    tooltip: {

                    },
                    data: maxBarDataArr
                }
            ]
        }
        updateChartOption(id, option);
    },
    // 平面柱图
    updatePlaneBarChart(chartData = [],keyList=[],nameList=[],id) {
        // 单位
        const unit = '人';
        let data = chartData;
        let series = [];
        keyList.forEach((keyName, index) => {
            series.push({
                name: nameList[index],
                stack: 'person',
                type: 'bar',
                data: data.map(item => item[keyName]),
                barMaxWidth: 22
            });
        });
        let option = {
            color: ['#17EE8B', '#25FEF1', '#00A0E9'],
            grid: {
                top: 30,
                left: 20,
                bottom: 0,
                right: 0,
                containLabel: true
            },
            xAxis: {
                data: data.map(item => item.name),
                axisLine: {
                    show: true
                },
                axisTick: {
                    show: false
                },
                axisLabel: {
                    fontFamily: 'customFont',
                    fontSize: 14,
                    color: 'rgba(189,189,189,0.6)'
                }
            },
            tooltip: {
                show: true,
                trigger: 'axis',
                axisPointer: {
                    type: 'shadow'
                }
            },
            legend: {
                show: true,
                right: 0,
                top: 0,
                icon: 'rect',
                itemWidth: 14,
                itemHeight: 10,
                textStyle: {
                    color: '#fff',
                    fontFamily: 'customFont',
                    fontSize: 14
                }
            },
            yAxis: {
                type: 'value',
                name: `单位：${unit}`,
                nameTextStyle: {
                    padding: [0, 0, 0, 10],
                    fontFamily: 'customFont',
                    color: 'rgba(255,255,255,0.5)',
                    fontSize: 14
                },
                axisLine: {
                    show: false
                },
                axisTick: {
                    show: false
                },
                axisLabel: {
                    color: 'rgba(189,189,189,0.6)',
                    fontFamily: 'customFont'
                },
                splitLine: {
                    lineStyle: {
                        type: 'dotted',
                        color: '#333'
                    }
                }
            },
            series: series
        }
        updateChartOption(id, option);
    },
    // 横向柱图
    updateLandscapeBarChart(chartData = [],id) {
        let nameArray = []; // 名称
        let numArray = []; // 值
        let totalArray = []; // 合计
        let symbolArray = []; // 条形图尾部标志
        let max = 0;
        // 只取前五条
        chartData.forEach(ele => {
            nameArray.push(ele.name);
            numArray.push(ele.value);
            max = ele.value > max ? Math.ceil(ele.value / 100) * 100 : max;
            symbolArray.push({
                value: ele.value,
                symbolPosition: 'end'
            });
        });

        // 如果返回了total数量
        totalArray = new Array(5).fill(max);
        let option = {
            grid: {
                top: 10,
                bottom: 0,
                left: 20,
                right: 20
            },
            tooltip: {
                // 格式化提示内容
                formatter: function (params) {
                    return params.name + '<br/>' +
                        "<span style='display:inline-block;margin-right:5px;border-radius:10px;width:9px;height:9px;background-color:#FDC131'></span>" +
                        '数量 : ' + numArray[params.dataIndex] + '<br/>'
                }
            },
            xAxis: {
                show: false,
                type: 'value'
            },
            yAxis: [{
                type: 'category',
                show: true,
                inverse: true,
                axisLabel: {
                    show: false,
                    textStyle: {
                        color: 'rgba(255,255,255,.6)'
                    },
                },
                splitLine: {
                    show: false
                },
                axisTick: {
                    show: false
                },
                axisLine: {
                    show: false
                },
                data: nameArray
            }, {
                type: 'category',
                inverse: true,
                axisTick: 'none',
                axisLine: 'none',
                show: true,
                axisLabel: {
                    textStyle: {
                        color: '#ffffff',
                        fontSize: '14'
                    },
                    align: 'right',
                    padding: [0, 8, 0, 0],
                    verticalAlign: 'bottom',
                    lineHeight: 36,
                    // 空闲车位、占比
                    formatter: function (value, index) {
                        return `{a|${value}}`;
                    },
                    rich: {
                        a: {
                            fontSize: 18,
                            fontFamily: 'OPPOSans',
                            padding: [0, 3, 0, 0]
                        }
                    }
                },
                data: numArray
            }],
            series: [
                // 条形图
                {
                    name: '数量',
                    type: 'bar',
                    zlevel: 1,
                    itemStyle: {
                        normal: {
                            color: new echarts.graphic.LinearGradient(0, 0, 1, 0, [{
                                offset: 0,
                                color: '#1FBF75'
                            }, {
                                offset: 1,
                                color: '#3CDC92'
                            }])
                        }
                    },
                    barWidth: 4,
                    data: numArray,
                    label: {
                        normal: {
                            color: '#fff',
                            show: true,
                            position: [0, '-23px'],
                            textStyle: {
                                fontSize: '14',
                                fontFamily: 'customFont',
                                color: '#FFFFFF'
                            },
                            // 序号、停车场名称
                            formatter: function (value) {
                                return `{a|${value.dataIndex + 1}}{b|${value.name}}`;
                            },
                            rich: {
                                a: {
                                    fontSize: 14,
                                    fontFamily: 'OPPOSans',
                                    color: '#1FBF75',
                                    width: 22,
                                    height: 14,
                                    align: 'center',
                                    verticalAlign: 'middle',
                                    backgroundColor: 'rgba(60, 220, 146, .1)',
                                    // padding: [0, 0, 3, 0]
                                },
                                b: {
                                    fontSize: '14',
                                    fontFamily: 'customFont',
                                    color: '#FFFFFF',
                                    padding: [0, 0, 0, 12]
                                }
                            }
                        }
                    }
                },
                // 背景条形图
                {
                    name: '背景',
                    type: 'bar',
                    barWidth: 4,
                    barGap: '-100%',
                    data: totalArray,
                    itemStyle: {
                        normal: {
                            color: '#47515C'
                        }
                    },
                },
                // 条形图尾部方块
                {
                    type: 'pictorialBar',
                    symbol: 'rect',
                    symbolSize: [4, 16],
                    symbolOffset: [3, 0],
                    zlevel: 2,
                    itemStyle: {
                        normal: {
                            color: new echarts.graphic.LinearGradient(0, 1, 0, 0, [{
                                offset: 0,
                                color: '#FBDD9E'
                            }, {
                                offset: 1,
                                color: '#FFFFFF'
                            }]),
                            shadowBlur: 5,
                            shadowOffsetY: 2,
                            shadowColor: 'rgba(0, 0, 0, 0.72)'
                        }
                    },
                    data: symbolArray
                }
            ]
        };
        updateChartOption(id, option);
    }
}