/**
 * 设置更新echarts
 * @param {*} id 
 * @param {*} option 
 */
function updateChartOption(id, option) {
    let currentDom = document.querySelector(`#${id}`);
    let myChart = echarts.getInstanceByDom(currentDom);
    if (!myChart) {
        myChart = echarts.init(currentDom);
    }
    myChart.setOption(option);
}

export default {
    // 带间隔的饼图
    updateGapPieChart(chartData = [], id) {
        console.log(id);
        let nameArray = []; // 名称
        let numArray = []; // 值
        let totalArray = []; // 合计
        let baseDataPie = [];
        let total = 0;

        const color = ['#37D3FF', '#16FFF1', '#FA7575'];

        chartData = chartData.slice(0, 3);
        chartData.forEach(item => {
            nameArray.push(item.name);
            numArray.push(item.value);
            total += item.value;
        });

        // 间隙
        let interval = total / 40;
        let dataPie = chartData;

        for (let i = 0; i < dataPie.length; i++) {
            baseDataPie.push({
                value: dataPie[i].value,
                name: dataPie[i].name,
                itemStyle: {
                    normal: {
                        color: color[i],
                        borderWidth: 0,
                        borderColor: color[i]
                    }
                }
            }, {
                value: interval * 2.5,
                name: '',
                itemStyle: {
                    normal: {
                        color: 'transparent',
                        borderWidth: 5,
                        borderColor: 'transparent',
                    }
                }
            });
        }
        let len = chartData.length;
        totalArray = new Array(len).fill(total);

        // 更新echarts图
        let option = {
            color,
            tooltip: {
                backgroundColor: 'rgba(50,50,50,0.7)',
                borderWidth: 0,
                padding: [5, 10],
                textStyle: {
                    color: '#FFFFFF',
                    fontFamily: 'sans-serif'
                },
                trigger: 'item',
                formatter: function (item) {
                    return `${item.name} ${item.value}%`;
                }
            },
            legend: {
                top: '5%',
                left: 'center',
                show: false,
            },
            series: [
                // 外圈
                {
                    name: '高发时段',
                    type: 'pie',
                    roundCap: 1,
                    radius: ['86%', '98%'],
                    center: ['50%', '50%'],
                    avoidLabelOverlap: false,
                    hoverAnimation: false,
                    label: {
                        show: false,
                        position: 'center'
                    },
                    labelLine: {
                        show: false
                    },
                    data: baseDataPie
                },
                // 内圈
                {
                    name: '高发时段',
                    type: 'pie',
                    selectedMode: 'single',
                    radius: ['70%', '83%'],
                    center: ['50%', '50%'],
                    itemStyle: {
                        color: 'rgba(55, 211, 255, 0.1)',
                    },
                    hoverAnimation: false,
                    tooltip: {
                        trigger: 'item',
                        show: false,
                    },
                    labelLine: {
                        show: false
                    },
                    data: totalArray
                }
            ]
        }

        updateChartOption(id, option);
    },
    // 带内圈阴影的饼图
    updateShadowPieChart(value,total,id) {
        // 格式化百分比
        const formatPercent = (num) => {
            if (num.toString().indexOf(".") > -1) {
                let arr = num.toString().split(".");
                let decimalArr = arr[1].split("");
                if (decimalArr.length > 2) {
                    return num.toFixed(2);
                } else {
                    return num;
                }
            } else {
                return num;
            }
        };
        let color = ['#38F0FF', '#0A7EB8']; //渐变色列表
        let point = value; //在线
        let handred = total; //全部

        let option = {
            // 标题
            title: {
                text: '{a|' + (formatPercent(point * 100 / handred)) + '}{b|%}\n{c|在线率}',
                x: 'center',
                y: 'center',
                textStyle: {
                    rich: {
                        a: {
                            color: '#FFFFFF',
                            fontSize: '26',
                            fontFamily: 'OPPOSans-M'
                        },
                        b: {
                            fontSize: '14',
                            fontFamily: 'OPPOSans-R',
                            color: '#FFFFFF',
                            padding: [0, 0, 7, 2]
                        },
                        c: {
                            fontSize: '16',
                            fontFamily: 'SourceHanSansCN-Normal',
                            color: '#BDE7FA',
                            padding: [5, 0, 6, 0]
                        }
                    }
                }
            },
            series: [{
                name: '',
                type: 'pie',
                hoverAnimation: false,
                clockWise: true,
                radius: ['66%', '74%'],
                itemStyle: {
                    normal: {
                        label: {
                            show: false
                        },
                        labelLine: {
                            show: false
                        }
                    }
                },
                data: [{
                    value: point,
                    name: '占比',
                    itemStyle: {
                        normal: {
                            color: {
                                // 颜色渐变
                                type: 'linear',
                                x: 0,
                                y: 0.2,
                                x2: 0,
                                y2: 1,
                                colorStops: [{
                                        offset: 0,
                                        color: color[0] // 0% 处的颜色
                                    },
                                    {
                                        offset: 0.6,
                                        color: 'rgba(56, 240, 255, 0.6)' // 60% 处的颜色
                                    },
                                    {
                                        offset: 1,
                                        color: color[1] // 100% 处的颜色
                                    }
                                ]
                            },
                            label: {
                                show: false
                            },
                            labelLine: {
                                show: false
                            }
                        }
                    }
                }, {
                    // 剩余背景透明
                    name: '剩余',
                    z: 1,
                    value: (handred - point) || 1,
                    itemStyle: {
                        normal: {
                            color: 'rgba(0, 0, 0, 0)'
                        }
                    }
                }]
            }]
        }
        updateChartOption(id, option);
    },
    // 带边框的饼图
    updateBorderPieChart(chartData=[],id) {
        // 副标题
        let subtext = '完成率';
        // 最大值
        let max = 100;
        let data = chartData.realComplete / chartData.planComplete * 100  + '';
        let option = {
            title: {
                text: `${data}%`,
                subtext,
                left: 'center',
                top: '35%',
                itemGap: 0,
                textStyle: {
                    color: '#FFFFFF',
                    fontSize: '25',
                    fontWeight: 400
                },
                subtextStyle: {
                    color: 'rgba(255, 255, 255, 0.4)',
                    fontSize: '17',
                    fontWeight: 400,
                    lineHeight: '30'
                }
            },
            angleAxis: {
                max,
                // 隐藏刻度线
                show: false,
                startAngle: 270
            },
            radiusAxis: {
                type: 'category',
                show: true,
                axisLabel: {
                    show: false,
                },
                axisLine: {
                    show: false,
                },
                axisTick: {
                    show: false
                },
            },
            polar: {
                radius: '185%' //图形大小
            },
            series: [{
                type: 'bar',
                roundCap: 1,
                data: [data],
                showBackground: true,
                backgroundStyle: {
                    color: '#666',
                },
                coordinateSystem: 'polar',
                barWidth: 4,
                itemStyle: {
                    normal: {
                        color: 'rgb(28,177,108)'
                    }
                },
            }]
        }
        updateChartOption(id, option);
    },
    // 多色饼图
    updateColorPieChart(chartData,id) {
        let data = chartData.caseOccupyData;
        // 总事件数
        let total = chartData.caseOccupyTotal;
        // 副标题
        let subtext = '总事件';
        // 配色数组
        let colors = ['rgba(30, 171, 107, 1)', 'rgba(0, 220, 255, 1)', 'rgba(211, 191, 6, 1)', 'rgba(248, 122, 66, 1)'];

        let option = {
            title: {
                text: total,
                subtext,
                left: 'center',
                top: '35%',
                itemGap: 0,
                textStyle: {
                    color: '#FFFFFF',
                    fontSize: '25',
                    fontWeight: 400
                },
                subtextStyle: {
                    color: 'rgba(255, 255, 255, 0.4)',
                    fontSize: '17',
                    fontWeight: 400,
                    lineHeight: '30'
                }
            },
            color: colors,
            legend: {
                itemWidth: 14,
                itemHeight: 8,
                show: true,
                left: "70%",
                top: "20%",
                formatter: (name) => {
                    return (
                        // {name|' + item.name + '}
                        "{name|" + name + "} {percent|" + data.find((item) => {
                            return item.name == name
                        }).percent + '%' + "}"
                    );
                },
                textStyle: {
                    color: "#beceff", //元字颜色
                    fontSize: 24,
                    rich: {
                        name: {
                            color: 'rgba(255, 255, 255, .6)',
                            fontSize: 12,
                        },
                        percent: {
                            color: '#FFFFFF',
                            fontSize: 12,
                        }
                    }
                },
            },
            tooltip: {
                show: true,
            },
            series: [
            {
                type: 'pie',
                roundCap: 0,
                hoverAnimation: false,
                radius: ['78%', '93%'],
                center: ['50%', '50%'],
                avoidLabelOverlap: false,
                label: {
                    show: false,
                    position: 'center'
                },
                emphasis: {
                    show: false,
                },
                labelLine: {
                    show: false
                },
                data: data,
            }]
        };
        updateChartOption(id, option);
    }
}