/**
 * 设置更新echarts
 * @param {*} id 
 * @param {*} option 
 */
 function updateChartOption(id, option) {
    let currentDom = document.querySelector(`#${id}`);
    let myChart = echarts.getInstanceByDom(currentDom);
    if (!myChart) {
        myChart = echarts.init(currentDom);
    }
    myChart.setOption(option);
}

export default {
    // 圆环图
    updateRingChart(chartData,id) {
        let barColor = ['#16FFF1', '#37D3FF', '#FA7575', '#FD9D66', '#FFE57C'].reverse();
        // 计算总和
        let total = 0;
        let data = chartData;
        data.forEach((item) => {
            total += item.value;
        });
        let value = data.map(item => item.name);

        let option = {
            angleAxis: {
                type: 'value',
                min: 0,
                max: 100,
                axisLine: {
                    show: false
                },
                axisTick: {
                    show: false
                },
                splitLine: {
                    show: false
                },
                axisLabel: {
                    show: false
                }
            },
            radiusAxis: {
                type: 'category',
                data: value,
                z: 100,
                axisLine: {
                    show: false
                },
                axisTick: {
                    show: false
                },
                axisLabel: {
                    show: false
                }
            },
            polar: {
                center: ['50%', '50%'],
                radius: ['20%', '96%']
            },
            tooltip: {
                show: true,
                formatter: (item) => {
                    return `<span>${ item.name }<br/><span style='display:inline-block;margin-right:5px;border-radius:10px;width:9px;height:9px;background-color:${ barColor[item.dataIndex] }'></span>占比：${((item.value / total) * 100).toFixed(0)}%</span>`;
                }
            },
            series: [{
                type: 'bar',
                coordinateSystem: 'polar',
                barWidth: 6, // 10条数据的时候 10
                barGap: 10,
                showBackground: true,
                backgroundStyle: {
                    color: 'rgba(89,113,126,.5)'
                },
                itemStyle: {
                    color: function (params) {
                        var idx = params.dataIndex;
                        return barColor[idx];
                    }
                },
                roundCap: true,
                data: data.reverse()
            }]
        };

        updateChartOption(id, option);
    }
}