/**
 * 设置更新echarts
 * @param {*} id 
 * @param {*} option 
 */
function updateChartOption(id, option) {
    let currentDom = document.querySelector(`#${id}`);
    let myChart = echarts.getInstanceByDom(currentDom);
    if (!myChart) {
        myChart = echarts.init(currentDom);
    }
    myChart.setOption(option);
}

// 初始化三维饼图
function updateThreeDPieChart(data, color, id) {
    let len = data.length - 1;
    // 格式化百分比
    const formatPercent = (num) => {
        if (num.toString().indexOf(".") > -1) {
            let arr = num.toString().split(".");
            let decimalArr = arr[1].split("");
            if (decimalArr.length > 2) {
                return num.toFixed(2);
            } else {
                return num;
            }
        } else {
            return num;
        }
    };
    let that = this;
    let each = this.Highcharts.each,
        round = Math.round,
        cos = Math.cos,
        sin = Math.sin,
        deg2rad = Math.deg2rad;
    this.Highcharts.wrap(this.Highcharts.seriesTypes.pie.prototype, 'translate', function (proceed) {
        proceed.apply(this, [].slice.call(arguments, 1));
        if (!this.chart.is3d()) {
            return;
        }
        let series = this,
            chart = series.chart,
            options = chart.options,
            seriesOptions = series.options,
            depth = seriesOptions.depth || 0,
            options3d = options.chart.options3d,
            alpha = options3d.alpha,
            beta = options3d.beta,
            z = seriesOptions.stacking ? (seriesOptions.stack || 0) * depth : series._i * depth;
        z += depth / 2;
        if (seriesOptions.grouping !== false) {
            z = 0;
        }
        each(series.data, function (point) {
            let shapeArgs = point.shapeArgs,
                angle;
            point.shapeType = 'arc3d';
            let ran = point.options.h;
            shapeArgs.z = z;
            shapeArgs.depth = depth * 0.75 + ran;
            shapeArgs.alpha = alpha;
            shapeArgs.beta = beta;
            shapeArgs.center = series.center;
            shapeArgs.ran = ran;
            angle = (shapeArgs.end + shapeArgs.start) / 2;
            point.slicedTranslation = {
                translateX: round(cos(angle) * seriesOptions.slicedOffset * cos(alpha * deg2rad)),
                translateY: round(sin(angle) * seriesOptions.slicedOffset * cos(alpha * deg2rad))
            };
        });
    });
    (function (H) {
        H.wrap(that.Highcharts.SVGRenderer.prototype, 'arc3dPath', function (proceed) {
            let ret = proceed.apply(this, [].slice.call(arguments, 1));
            ret.zTop = (ret.zOut + 0.5) / 100;
            return ret;
        });
    }(that.Highcharts));
    this.Highcharts.chart(id, {
        chart: {
            type: 'pie',
            animation: true,
            marginLeft: 0,
            marginTop: 30,
            marginRight: 0,
            marginBottom: 0,
            events: {
                load: function () {
                    let each = that.Highcharts.each,
                        points = this.series[0].points;
                    each(points, function (p, i) {
                        p.graphic.attr({
                            translateY: -p.shapeArgs.ran
                        });
                        p.graphic.side1.attr({
                            translateY: -p.shapeArgs.ran
                        });
                        p.graphic.side2.attr({
                            translateY: -p.shapeArgs.ran
                        });
                    });
                }
            },
            options3d: {
                enabled: true,
                alpha: 60,
                beta: 0
            },
            backgroundColor: 'none'
        },
        title: {
            text: ''
        },
        accessibility: {
            point: {
                valueSuffix: '%'
            }
        },
        plotOptions: {
            pie: {
                allowPointSelect: false,
                cursor: 'pointer',
                depth: 20,
                dataLabels: {
                    enabled: false
                },
                showInLegend: true,
                point: {
                    events: {
                        legendItemClick: function () {
                            return false; // 直接 return false 即可禁用图例点击事件
                        }
                    }
                }
            },
        },
        legend: {
            // enabled: false, //是否显示图例
            align: 'right', //水平方向位置
            verticalAlign: 'top', //垂直方向位置
            x: 33, //距离x轴的距离
            y: -5, //距离Y轴的距离
            // itemMarginBottom: 28,
            floating: true,
            width: 200,
            height: 280,
            useHTML: true,
            symbolWidth: 10,
            symbolHeight: 10,
            symbolRadius: 0, //图标圆角
            symbolPadding: 7, //图标跟文字的间距
            labelFormatter: function () {
                return `
                        <div class="device-archives-content" style="margin-bottom:${this.index < len ? 32 : 0}px">
                            <div class="name">${this.name}</div>
                            <div class="count">
                                ${this.y}
                                <span class="split"></span>
                                <div title="${this.percentage ? formatPercent(this.y * 100 / this.total) : '-'}%" class="percent text-overflow" style="color:${color[this.index]}">${this.percentage ? formatPercent(this.y * 100 / this.total) : '-'}%</div>
                            </div>
                        </div>
                    `;
            }
        },
        tooltip: {
            backgroundColor: 'rgba(50, 50, 50, 0.7)', //数据提示框的背景颜色
            borderColor: '#333', //边框颜色
            borderWidth: 0,
            borderRadius: 10,
            useHTML: true, //是否使用HTML编辑提示信息
            formatter: function () {
                return '<div style="color:#fff;font-family:sans-serif;font-size:14px;font-weight:normal;padding:0;display:flex;flex-direction:column"><span>' + this.key +
                    `</span><span style="margin-top:3px"><span style="display:inline-block;margin-right:5px;border-radius:10px;width:9px;height:9px;background-color:${this.color}"></span>报警数量 : ` + this.y + '</span></div>'
            },
        },
        series: [{
            type: 'pie',
            name: '报警数量',
            data: data
        }]
    });
};
export default {
    updateThreeDPieChart
}